@@ -11,10 +11,23 @@ def format_data(message: Dict[AnyStr, Any]) -> bytes:
         _clave_to_bytearray(message['op_ins_clave']),
         _to_byte_array(message['op_cve_rastreo'], add_zero_byte=True),
         _monto_to_bytearray(message['op_monto']),
-        _to_byte_array(message['op_cuenta_ord'], add_zero_byte=True),
-        _to_byte_array(message['op_cuenta_ben'], add_zero_byte=True),
     ]
 
+    if 'op_cuenta_ord' in message:
+        message_data.append(
+            _to_byte_array(message['op_cuenta_ord'], add_zero_byte=True),
+        )
+
+    if 'op_cuenta_ben' in message:
+        message_data.append(
+            _to_byte_array(message['op_cuenta_ben'], add_zero_byte=True),
+        )
+
+    if 'op_cuenta_ben_2' in message:
+        message_data.append(
+            _to_byte_array(message['op_cuenta_ben_2'], add_zero_byte=True),
+        )
+
     return _list_to_bytes(message_data)
 
 
